==> faxtomail-persistence-1.0-sources.jar: com/franciaflex/faxtomail/persistence/entities/HistoryImpl.java <==
package com.franciaflex.faxtomail.persistence.entities;

/*
 * #%L
 * FaxToMail :: Persistence
 * $Id: HistoryImpl.java 660 2014-10-02 11:30:33Z kmorin $
 * $HeadURL: http://svn.codelutin.com/faxtomail/tags/faxtomail-1.0/faxtomail-persistence/src/main/java/com/franciaflex/faxtomail/persistence/entities/HistoryImpl.java $
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import java.lang.reflect.Type;
import java.util.Set;

import com.google.gson.reflect.TypeToken;

public class HistoryImpl extends HistoryAbstract {

    /** serialVersionUID. */
    private static final long serialVersionUID = 7357010358014312848L;

    private static final Type SET_STRING_GSON_TYPE = new TypeToken<Set<String>>() {}.getType();

    @Override
    public void setFields(Set<String> field) {
        String json = AbstractFaxToMailTopiaDao.GSON_INSTANCE.toJson(field);
        setFieldsJson(json);
    }

    @Override
    public Set<String> getFields() {
        String json = getFieldsJson();
        Set<String> fields = AbstractFaxToMailTopiaDao.GSON_INSTANCE.fromJson(json, SET_STRING_GSON_TYPE);
        return fields;
    }

}

==> faxtomail-persistence-2.0-sources.jar: com/franciaflex/faxtomail/persistence/entities/HistoryImpl.java <==
package com.franciaflex.faxtomail.persistence.entities;

/*
 * #%L
 * FaxToMail :: Persistence
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.gson.reflect.TypeToken;

import java.lang.reflect.Type;
import java.util.Set;

public class HistoryImpl extends HistoryAbstract {

    /** serialVersionUID. */
    private static final long serialVersionUID = 7357010358014312848L;

    private static final Type SET_STRING_GSON_TYPE = new TypeToken<Set<String>>() {}.getType();

    @Override
    public void setFields(Set<String> field) {
        String json = AbstractFaxToMailTopiaDao.GSON_INSTANCE.toJson(field);
        setFieldsJson(json);
    }

    @Override
    public Set<String> getFields() {
        String json = getFieldsJson();
        Set<String> fields = AbstractFaxToMailTopiaDao.GSON_INSTANCE.fromJson(json, SET_STRING_GSON_TYPE);
        return fields;
    }

}
